@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtSensors module of the Qt Toolkit.
 **
@@ -10,9 +10,9 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -23,8 +23,8 @@
 ** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** $QT_END_LICENSE$
@@ -82,8 +82,8 @@ bool genericrotationsensor::filter(QSensorReading *reading)
 
     // Note that the formula used come from this document:
     // http://www.freescale.com/files/sensors/doc/app_note/AN3461.pdf
-    pitch = qAtan(y / sqrt(x*x + z*z)) * RADIANS_TO_DEGREES;
-    roll = qAtan(x / sqrt(y*y + z*z)) * RADIANS_TO_DEGREES;
+    pitch = qAtan(y / qSqrt(x*x + z*z)) * RADIANS_TO_DEGREES;
+    roll = qAtan(x / qSqrt(y*y + z*z)) * RADIANS_TO_DEGREES;
     // Roll is a left-handed rotation but we need right-handed rotation
     roll = -roll;
 
@@ -92,7 +92,7 @@ bool genericrotationsensor::filter(QSensorReading *reading)
     // Note that theta is defined as the angle of the Z axis relative
     // to gravity (see referenced document). It's negative when the
     // face of the device points downward.
-    qreal theta = qAtan(sqrt(x*x + y*y) / z) * RADIANS_TO_DEGREES;
+    qreal theta = qAtan(qSqrt(x*x + y*y) / z) * RADIANS_TO_DEGREES;
     if (theta < 0) {
         if (roll > 0)
             roll = 180 - roll;
